/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __TIZEN_CAPI_NETWORK_USER_AWARENESS_LOG_H__
#define __TIZEN_CAPI_NETWORK_USER_AWARENESS_LOG_H__

#include <dlog.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifdef LOG_TAG
#undef LOG_TAG
#endif
#define LOG_TAG "UA_CAPI"

#define LOG_COLOR_RESET		"\033[0m"
#define LOG_COLOR_RED		"\033[31m"
#define LOG_COLOR_YELLOW	"\033[33m"
#define LOG_COLOR_GREEN		"\033[32m"
#define LOG_COLOR_BLUE		"\033[36m"
#define LOG_COLOR_PURPLE	"\033[35m"

#define UA_DBG(fmt, args...) \
	SLOGD(fmt, ##args)
#define UA_INFO(fmt, args...) \
	SLOGI(fmt, ##args)
#define UAM_INFO_C(fmt, arg...) \
	SLOGI_IF(TRUE, LOG_COLOR_GREEN" "fmt" "LOG_COLOR_RESET, ##arg)
#define UA_WARN(fmt, arg...) \
	SLOGI_IF(TRUE, LOG_COLOR_YELLOW" "fmt" "LOG_COLOR_RESET, ##arg)
#define UA_ERR(fmt, arg...) \
	SLOGI_IF(TRUE, LOG_COLOR_RED" "fmt" "LOG_COLOR_RESET, ##arg)

#define UA_DEPRECATED_LOG(origin, substitution) \
	SLOGI("DEPRECATION WARNING: %s() is deprecated and will be removed " \
		"from next release. Use %s() instead.", origin, substitution)

#define FUNC_ENTRY UA_DBG("+")
#define FUNC_EXIT UA_DBG("-")

#ifdef __cplusplus
}
#endif
#endif /* __TIZEN_CAPI_NETWORK_USER_AWARENESS_LOG_H__ */
