/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
#ifndef __UAT_COMMON_H__
#define __UAT_COMMON_H__

#include <user-awareness.h>
#include <user-awareness-internal.h>

#include "uat-menu.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef enum {
	UAT_SENSOR_TYPE_BT = 1,
	UAT_SENSOR_TYPE_BLE = 2,
	UAT_SENSOR_TYPE_WIFI = 3,
	UAT_SENSOR_TYPE_MOTION = 4,
	UAT_SENSOR_TYPE_LIGHT = 5,
	UAT_SENSOR_TYPE_AUDIO = 6,
	UAT_SENSOR_TYPE_MAX
} uat_sensor_type_e;

typedef enum {
	UAT_MAC_TYPE_BT = 1,
	UAT_MAC_TYPE_BLE = 2,
	UAT_MAC_TYPE_WIFI = 3,
	UAT_MAC_TYPE_P2P = 4,
	UAT_MAC_TYPE_MAX
} uat_mac_type_e;

typedef enum {
	UAT_PRESENCE = 1,
	UAT_ABSENCE = 2
} uat_detection_type_e;

const char* uat_get_error_str(int err);
const char* uat_get_sensor_str(int sensors);
const char* uat_get_mac_type_str(int sensor);
const char* uat_get_str_from_uat_mac_type(int mac_type);
const char* uat_get_sensor_bitmask_str(int sensor);
char* uat_get_time(void);
const char * uat_convert_device_mac_type_to_txt(int mac_type);
void uat_print_device_uid(const char *device_uid);
void uat_clear_device_list(void);
ua_mac_type_e uat_convert_idx_to_device_type(int idx);
uat_mac_type_e uat_convert_device_type_to_idx(int mac_type);
void uat_update_device_info(void);
void uat_print_device_uid(const char *device_uid);
void uat_clear_user_list(void);
void uat_clear_service_list(void);
int uat_select_device(MManager *mm, struct menu_data *menu);
int uat_select_user(MManager *mm, struct menu_data *menu);

int _uat_service_create();

int _uat_user_create();

int _uat_monitor_create();
int _uat_monitor_set_sensor_status_cb();

void _print_device_info(ua_device_h handle);
void _sensor_presence_detected_cb(int result, ua_monitor_h monitor,
		ua_sensor_type_e sensor, ua_service_h service_handle,
		ua_device_h device_handle, ua_sensor_h sensor_handle,
		void *user_data);
void _sensor_absence_detected_cb(int result, ua_monitor_h monitor,
	ua_service_h service_handle, ua_sensor_type_e sensor,
	ua_sensor_h sensor_handle, void *user_data);
void _sensor_location_detected_cb(int result, ua_monitor_h monitor,
		ua_service_h service_handle, ua_sensor_type_e sensor,
		ua_sensor_h sensor_handle, ua_device_h device_handle,
		ua_user_h user_handle, ua_location_h location_handle,
		void *user_data);
bool _foreach_registered_user_cb(
	ua_user_h user_handle, void *user_data);
bool _foreach_added_service_cb(
	ua_service_h service_handle, void *user_data);
bool _foreach_added_device_cb(
	ua_device_h device_handle, void *user_data);

#define UA_SENSOR_WIFI_LOCATION 0x00000040
#define UA_MAC_TYPE_WIFI_LOCATION 0x10
#define UA_SENSOR_UWB 0x00000080
#define UA_MAC_TYPE_UWB 0x20

#ifdef __cplusplus
}
#endif

#endif /* __UAT_COMMON_H__ */
