/*
 * Copyright (c) 2021 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef _USER_AWARENESS_UTC_COMMON_H_
#define _USER_AWARENESS_UTC_COMMON_H_

#include <tct_common.h>
#include <system_info.h>
#include <user-awareness.h>
#include <glib.h>
#include <dlog.h>

#define GMAINTIMEOUT 10000
#define UA_FEATURE "http://tizen.org/feature/user_awareness"

#define CASE_TO_STR(x) case x: return #x;

extern GMainLoop *g_pMainLoop;
extern guint g_nTimeoutId;
extern int g_nCallbackRet;
extern bool g_bInitialized;
extern bool g_bFeatureUA;

#define RUN_GMAIN_LOOP {\
	g_pMainLoop = g_main_loop_new(NULL, false);\
	g_nTimeoutId = g_timeout_add(GMAINTIMEOUT, ua_callback_timeout, g_pMainLoop);\
	if (COMMON_DEBUG) {\
		PRINT_LOG(DLOG_INFO, "NativeTCT", "[Line:%5d][%s] Run mainloop [%p]",\
				__LINE__, __FUNCTION__, g_pMainLoop);\
	} \
	g_main_loop_run(g_pMainLoop);\
	g_source_remove(g_nTimeoutId);\
	g_pMainLoop = NULL;\
}

#define QUIT_GMAIN_LOOP {\
	if (COMMON_DEBUG) {\
		PRINT_LOG(DLOG_INFO, "NativeTCT", "[Line:%5d][%s] Quit mainloop [%p]",\
			__LINE__, __FUNCTION__, g_pMainLoop);\
	} \
	g_main_loop_quit(g_pMainLoop);\
}

#define FREE_MEMORY(var) {\
	if (var != NULL) {\
		g_free(var);\
		var = NULL;\
	} \
}

#define PRINT_RETURN(api, ret) {\
	if (COMMON_DEBUG) {\
		PRINT_LOG(DLOG_INFO, "NativeTCT", "[Line:%5d][%s] %s returned = %s",\
			__LINE__, __FUNCTION__, api, ua_error_to_string(ret));\
	} \
}

#define CHECK_INIT_RETURN(var) {\
	if (!var) {\
		if (COMMON_DEBUG) {\
			PRINT_LOG(DLOG_INFO, "NativeTCT", "[Line:%5d][%s] UA is not initialized",\
				__LINE__, __FUNCTION__);\
		} \
		return 1;\
	} \
}

#define CHECK_RETURN(api, ret, val) {\
	if (ret != val) {\
		if (COMMON_DEBUG) {\
			PRINT_LOG(DLOG_INFO, "NativeTCT", "[Line:%5d][%s] %s failed, error returned = %s",\
				__LINE__, __FUNCTION__, api, ua_error_to_string(ret));\
		} \
		return 1;\
	} else {\
		if (COMMON_DEBUG) {\
			PRINT_LOG(DLOG_INFO, "NativeTCT", "[Line:%5d][%s] %s",\
				__LINE__, __FUNCTION__, api);\
		} \
	} \
}

#define DEBUG_LOG(str) {\
	if (COMMON_DEBUG) {\
		PRINT_LOG(DLOG_INFO, "NativeTCT", "[Line:%5d][%s] ***** DEBUG [%s] *****",\
			__LINE__, __FUNCTION__, str);\
	} \
}

gboolean ua_callback_timeout(gpointer data);

const char* ua_error_to_string(ua_error_e err);

bool ua_check_feature_supported(char *key);

#endif  /* _USER_AWARENESS_UTC_COMMON_H_ */
